@@ -10,10 +10,11 @@ $container = new ContainerBuilder();
 $container
     ->register('foo', FooClass::class)
     ->addTag('foo_tag', [
+        'name' => 'attributeName',
         'foo' => 'bar',
         'bar' => [
             'foo' => 'bar',
-            'bar' => 'foo'
+            'bar' => 'foo',
         ]])
 ;
 
